@@ -1,6 +1,9 @@
 import flask
 import logging
 from flask import send_file, abort, safe_join
+import random
+import webbrowser
+from rich import print
 
 log = logging.getLogger('werkzeug')
 log.setLevel(logging.ERROR)
@@ -31,3 +34,14 @@ def report_data():
         return send_file(safe_path, as_attachment=True)
     except FileNotFoundError:
         abort(404)
+
+
+if __name__ == '__main__':
+    app.static_folder = '.'
+    app.template_folder = '.'
+    application_folder = '.'
+    port = random.randint(1024, 49151)
+
+    print(f'Serving report on [link=http://127.0.0.1:{port}]http://127.0.0.1:{port}[/link]')
+    webbrowser.open(f'http://127.0.0.1:{port}')
+    app.run(port=port)
